@@ -128,9 +128,14 @@ def acquire_lock_1(force, lock_file=None):
         if not force:
             raise
         # Force removal of lock first.
-        lock.disown()
         hostname, pid, tempfile = lock.details
         os.unlink(lock_file)
+        # Also remove any stale claim files.
+        dname = os.path.dirname(lock_file)
+        for fname in os.listdir(dname):
+            fpath = os.path.join(dname, fname)
+            if fpath.startswith(lock_file):
+                os.unlink(fpath)
         return acquire_lock_1(force=False)
 
 
@@ -443,8 +448,8 @@ Master detected subprocess exit
             # See if we've reached the maximum number of allowable restarts.
             if restarts > max_restarts:
                 log.info("""\
-Runner {0} reached maximum restart limit of {1:d}, not restarting.""",
-                         rname, max_restarts)
+Runner {0} reached maximum restart limit of {1:d}, not restarting.""".format(
+                         rname, max_restarts))
             # Now perhaps restart the process unless it exited with a
             # SIGTERM or we aren't restarting.
             if restart:
