@@ -90,6 +90,15 @@ class SubscriptionPolicy(Enum):
     confirm_then_moderate = 3
 
 
+@public
+class ArchiveRenderingMode(Enum):
+    """Email rendering mode in Archiver."""
+    # Default text.
+    text = 1
+    # Render emails as markdown text.
+    markdown = 2
+
+
 @public
 class IMailingList(Interface):
     """A mailing list."""
@@ -747,6 +756,18 @@ class IMailingList(Interface):
         """The NNTP server's message number of the last post gated to the
         list.""")
 
+    # Hyperkitty specific settings.
+
+    archive_rendering_mode = Attribute(
+        """How are Emails rendered in archivers?  This is only a suggested mode
+        for Archivers and is not related to actual contents of Emails.
+
+        Primary use of this setting is going to be Hyperkitty, which can render
+        emails as markdown text.
+
+        Values are `ArchiveRenderingMode` Enum.
+        """)
+
 
 @public
 class IAcceptableAlias(Interface):
